all.Cycss<-function(){
     cat("\n")
     note_for_Cycss_input()
     cat("\n")
     note_for_close_window()
     CycSSpar<-data.frame(parameter=c("bw (kg)","PTD (day)","Dia","D (mg)","tau (hr)","ts (hr)","c (mcg/L)"),value=c(0))
     CycSSpar<-edit(CycSSpar)
##     CycSSpar<-ycheck(CycSSpar)
     cat("\n")
     Cyc.ss(CycSSpar[7,2],CycSSpar[2,2],CycSSpar[5,2],CycSSpar[6,2],CycSSpar[4,2],CycSSpar[1,2],CycSSpar[3,2])
     note_for_convergence_plots()
     convergence_plots_sep()
     note_for_Cycss_output()
     show(samplesStats("*"))
     cat("\n") 
     C<-Cyccpr(CycSSpar[2,2],CycSSpar[1,2],CycSSpar[4,2],CycSSpar[5,2],CycSSpar[6,2])
     sim<-matrix(C[1 ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Cmss_pr (mg/L)")
     output1<-coutput
     show(coutput)
     C<-Cyccpr(CycSSpar[2,2],CycSSpar[1,2],CycSSpar[4,2],CycSSpar[5,2],CycSSpar[5,2])
     sim<-matrix(C[1 ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Ctss_pr (mg/L)")
     output2<-coutput
     show(coutput)    
     cat("\n")   
     Cyc.more(CycSSpar[2,2],CycSSpar[1,2])
}